# TheForensicator

[![Release Status](https://img.shields.io/pypi/v/theforensicator.svg)](https://pypi.python.org/pypi/theforensicator)
[![CI Status](https://github.com/ValekoZ/theforensicator/actions/workflows/release.yml/badge.svg)](https://github.com/ValekoZ/theforensicator/actions)
[![Documentation Status](https://img.shields.io/website/https/ValekoZ.github.io/TheForensicator/index.html.svg?label=docs&down_message=unavailable&up_message=available)](https://ValekoZ.github.io/TheForensicator/)


School project for forensic investigations


* Free software: MIT
* Documentation: <https://ValekoZ.github.io/TheForensicator/>


## Features

* [X] Read a EWF file
* [X] Extract MBR from NTFS partitions
* [X] Resolve paths of files from NTFS partitions
* [X] Extract files from NTFS partitions
* [X] Extract list of files from NFTS partitons using yaml file as a list

## Credits

This package was created with the [ppw](https://zillionare.github.io/python-project-wizard) tool. For more information, please visit the [project page](https://zillionare.github.io/python-project-wizard/).
